summaryrefslogtreecommitdiffstats
path: root/ui/base
diff options
context:
space:
mode:
authoruekawa@chromium.org <uekawa@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-01-27 03:23:32 +0000
committeruekawa@chromium.org <uekawa@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-01-27 03:23:32 +0000
commit3f8340c8669b1884bdd7c2b07611e0fad6c7f3e6 (patch)
treec75beae87c99fc410f2e8ca5f5a4cc90a1901b6c /ui/base
parent5cc864ce6ebd2f4f069d0eecc8c8c4bbebb4b2ac (diff)
downloadchromium_src-3f8340c8669b1884bdd7c2b07611e0fad6c7f3e6.zip
chromium_src-3f8340c8669b1884bdd7c2b07611e0fad6c7f3e6.tar.gz
chromium_src-3f8340c8669b1884bdd7c2b07611e0fad6c7f3e6.tar.bz2
Rename IBusBridge to IMEBridge, and IBusEngineHandlerInterface to IMEEngineHandlerInterface
This code is about IME Engine singleton and IBus implementation no longer exists. BUG=283612 Review URL: https://codereview.chromium.org/134993003 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@247191 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ui/base')
-rw-r--r--ui/base/ime/chromeos/ime_bridge.cc (renamed from ui/base/ime/chromeos/ibus_bridge.cc)70
-rw-r--r--ui/base/ime/chromeos/ime_bridge.h (renamed from ui/base/ime/chromeos/ibus_bridge.h)43
-rw-r--r--ui/base/ime/chromeos/mock_ime_candidate_window_handler.h2
-rw-r--r--ui/base/ime/chromeos/mock_ime_engine_handler.h4
-rw-r--r--ui/base/ime/chromeos/mock_ime_input_context_handler.h2
-rw-r--r--ui/base/ime/ime.gypi4
-rw-r--r--ui/base/ime/input_method_chromeos.cc16
-rw-r--r--ui/base/ime/input_method_chromeos.h4
-rw-r--r--ui/base/ime/input_method_chromeos_unittest.cc16
-rw-r--r--ui/base/ime/input_method_initializer.cc10
10 files changed, 85 insertions, 86 deletions
diff --git a/ui/base/ime/chromeos/ibus_bridge.cc b/ui/base/ime/chromeos/ime_bridge.cc
index bf10ebe..fade3eb 100644
--- a/ui/base/ime/chromeos/ibus_bridge.cc
+++ b/ui/base/ime/chromeos/ime_bridge.cc
@@ -1,8 +1,8 @@
-// Copyright 2013 The Chromium Authors. All rights reserved.
+// Copyright 2014 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#include "ui/base/ime/chromeos/ibus_bridge.h"
+#include "ui/base/ime/chromeos/ime_bridge.h"
#include <map>
#include "base/logging.h"
@@ -10,43 +10,43 @@
namespace chromeos {
-static IBusBridge* g_ibus_bridge = NULL;
+static IMEBridge* g_ime_bridge = NULL;
-// An implementation of IBusBridge.
-class IBusBridgeImpl : public IBusBridge {
+// An implementation of IMEBridge.
+class IMEBridgeImpl : public IMEBridge {
public:
- IBusBridgeImpl()
+ IMEBridgeImpl()
: input_context_handler_(NULL),
engine_handler_(NULL),
candidate_window_handler_(NULL) {
}
- virtual ~IBusBridgeImpl() {
+ virtual ~IMEBridgeImpl() {
}
- // IBusBridge override.
+ // IMEBridge override.
virtual IBusInputContextHandlerInterface*
GetInputContextHandler() const OVERRIDE {
return input_context_handler_;
}
- // IBusBridge override.
+ // IMEBridge override.
virtual void SetInputContextHandler(
IBusInputContextHandlerInterface* handler) OVERRIDE {
input_context_handler_ = handler;
}
- // IBusBridge override.
+ // IMEBridge override.
virtual void SetEngineHandler(
const std::string& engine_id,
- IBusEngineHandlerInterface* handler) OVERRIDE {
+ IMEEngineHandlerInterface* handler) OVERRIDE {
DCHECK(!engine_id.empty());
DCHECK(handler);
engine_handler_map_[engine_id] = handler;
}
- // IBusBridge override.
- virtual IBusEngineHandlerInterface* GetEngineHandler(
+ // IMEBridge override.
+ virtual IMEEngineHandlerInterface* GetEngineHandler(
const std::string& engine_id) OVERRIDE {
if (engine_id.empty() ||
engine_handler_map_.find(engine_id) == engine_handler_map_.end()) {
@@ -55,14 +55,14 @@ class IBusBridgeImpl : public IBusBridge {
return engine_handler_map_[engine_id];
}
- // IBusBridge override.
+ // IMEBridge override.
virtual void SetCurrentEngineHandler(
- IBusEngineHandlerInterface* handler) OVERRIDE {
+ IMEEngineHandlerInterface* handler) OVERRIDE {
engine_handler_ = handler;
}
- // IBusBridge override.
- virtual IBusEngineHandlerInterface* SetCurrentEngineHandlerById(
+ // IMEBridge override.
+ virtual IMEEngineHandlerInterface* SetCurrentEngineHandlerById(
const std::string& engine_id) OVERRIDE {
if (engine_id.empty()) {
engine_handler_ = NULL;
@@ -74,18 +74,18 @@ class IBusBridgeImpl : public IBusBridge {
return engine_handler_;
}
- // IBusBridge override.
- virtual IBusEngineHandlerInterface* GetCurrentEngineHandler() const OVERRIDE {
+ // IMEBridge override.
+ virtual IMEEngineHandlerInterface* GetCurrentEngineHandler() const OVERRIDE {
return engine_handler_;
}
- // IBusBridge override.
+ // IMEBridge override.
virtual IBusPanelCandidateWindowHandlerInterface*
GetCandidateWindowHandler() const OVERRIDE {
return candidate_window_handler_;
}
- // IBusBridge override.
+ // IMEBridge override.
virtual void SetCandidateWindowHandler(
IBusPanelCandidateWindowHandlerInterface* handler) OVERRIDE {
candidate_window_handler_ = handler;
@@ -93,36 +93,36 @@ class IBusBridgeImpl : public IBusBridge {
private:
IBusInputContextHandlerInterface* input_context_handler_;
- IBusEngineHandlerInterface* engine_handler_;
+ IMEEngineHandlerInterface* engine_handler_;
IBusPanelCandidateWindowHandlerInterface* candidate_window_handler_;
- std::map<std::string, IBusEngineHandlerInterface*> engine_handler_map_;
+ std::map<std::string, IMEEngineHandlerInterface*> engine_handler_map_;
- DISALLOW_COPY_AND_ASSIGN(IBusBridgeImpl);
+ DISALLOW_COPY_AND_ASSIGN(IMEBridgeImpl);
};
///////////////////////////////////////////////////////////////////////////////
-// IBusBridge
-IBusBridge::IBusBridge() {
+// IMEBridge
+IMEBridge::IMEBridge() {
}
-IBusBridge::~IBusBridge() {
+IMEBridge::~IMEBridge() {
}
// static.
-void IBusBridge::Initialize() {
- if (!g_ibus_bridge)
- g_ibus_bridge = new IBusBridgeImpl();
+void IMEBridge::Initialize() {
+ if (!g_ime_bridge)
+ g_ime_bridge = new IMEBridgeImpl();
}
// static.
-void IBusBridge::Shutdown() {
- delete g_ibus_bridge;
- g_ibus_bridge = NULL;
+void IMEBridge::Shutdown() {
+ delete g_ime_bridge;
+ g_ime_bridge = NULL;
}
// static.
-IBusBridge* IBusBridge::Get() {
- return g_ibus_bridge;
+IMEBridge* IMEBridge::Get() {
+ return g_ime_bridge;
}
} // namespace chromeos
diff --git a/ui/base/ime/chromeos/mock_ime_candidate_window_handler.h b/ui/base/ime/chromeos/mock_ime_candidate_window_handler.h
index 8d30231..718afbc 100644
--- a/ui/base/ime/chromeos/mock_ime_candidate_window_handler.h
+++ b/ui/base/ime/chromeos/mock_ime_candidate_window_handler.h
@@ -6,7 +6,7 @@
#define UI_BASE_IME_CHROMEOS_MOCK_IME_CANDIDATE_WINDOW_HANDLER_H_
#include "ui/base/ime/candidate_window.h"
-#include "ui/base/ime/chromeos/ibus_bridge.h"
+#include "ui/base/ime/chromeos/ime_bridge.h"
#include "ui/base/ui_base_export.h"
namespace chromeos {
diff --git a/ui/base/ime/chromeos/mock_ime_engine_handler.h b/ui/base/ime/chromeos/mock_ime_engine_handler.h
index af6097f..bea6a8b 100644
--- a/ui/base/ime/chromeos/mock_ime_engine_handler.h
+++ b/ui/base/ime/chromeos/mock_ime_engine_handler.h
@@ -5,13 +5,13 @@
#ifndef UI_BASE_IME_CHROMEOS_MOCK_IME_ENGINE_HANDLER_H_
#define UI_BASE_IME_CHROMEOS_MOCK_IME_ENGINE_HANDLER_H_
-#include "ui/base/ime/chromeos/ibus_bridge.h"
+#include "ui/base/ime/chromeos/ime_bridge.h"
#include "ui/base/ui_base_export.h"
#include "ui/events/event.h"
namespace chromeos {
-class UI_BASE_EXPORT MockIMEEngineHandler : public IBusEngineHandlerInterface {
+class UI_BASE_EXPORT MockIMEEngineHandler : public IMEEngineHandlerInterface {
public:
MockIMEEngineHandler();
virtual ~MockIMEEngineHandler();
diff --git a/ui/base/ime/chromeos/mock_ime_input_context_handler.h b/ui/base/ime/chromeos/mock_ime_input_context_handler.h
index 66823eb..873cba4 100644
--- a/ui/base/ime/chromeos/mock_ime_input_context_handler.h
+++ b/ui/base/ime/chromeos/mock_ime_input_context_handler.h
@@ -6,7 +6,7 @@
#define UI_BASE_IME_CHROMEOS_MOCK_IME_INPUT_CONTEXT_HANDLER_H_
#include "chromeos/ime/ibus_text.h"
-#include "ui/base/ime/chromeos/ibus_bridge.h"
+#include "ui/base/ime/chromeos/ime_bridge.h"
#include "ui/base/ui_base_export.h"
namespace chromeos {
diff --git a/ui/base/ime/ime.gypi b/ui/base/ime/ime.gypi
index 7850caf..b09ba55 100644
--- a/ui/base/ime/ime.gypi
+++ b/ui/base/ime/ime.gypi
@@ -11,8 +11,8 @@
'candidate_window.h',
'chromeos/character_composer.cc',
'chromeos/character_composer.h',
- 'chromeos/ibus_bridge.cc',
- 'chromeos/ibus_bridge.h',
+ 'chromeos/ime_bridge.cc',
+ 'chromeos/ime_bridge.h',
'chromeos/mock_ime_candidate_window_handler.cc',
'chromeos/mock_ime_candidate_window_handler.h',
'chromeos/mock_ime_engine_handler.cc',
diff --git a/ui/base/ime/input_method_chromeos.cc b/ui/base/ime/input_method_chromeos.cc
index bf2b9b9..e12697e 100644
--- a/ui/base/ime/input_method_chromeos.cc
+++ b/ui/base/ime/input_method_chromeos.cc
@@ -29,8 +29,8 @@
#include "ui/gfx/rect.h"
namespace {
-chromeos::IBusEngineHandlerInterface* GetEngine() {
- return chromeos::IBusBridge::Get()->GetCurrentEngineHandler();
+chromeos::IMEEngineHandlerInterface* GetEngine() {
+ return chromeos::IMEBridge::Get()->GetCurrentEngineHandler();
}
} // namespace
@@ -46,7 +46,7 @@ InputMethodChromeOS::InputMethodChromeOS(
previous_textinput_type_(TEXT_INPUT_TYPE_NONE),
weak_ptr_factory_(this) {
SetDelegate(delegate);
- chromeos::IBusBridge::Get()->SetInputContextHandler(this);
+ chromeos::IMEBridge::Get()->SetInputContextHandler(this);
UpdateContextFocusState();
OnInputMethodChanged();
@@ -59,7 +59,7 @@ InputMethodChromeOS::~InputMethodChromeOS() {
// We are dead, so we need to ask the client to stop relying on us.
OnInputMethodChanged();
- chromeos::IBusBridge::Get()->SetInputContextHandler(NULL);
+ chromeos::IMEBridge::Get()->SetInputContextHandler(NULL);
}
void InputMethodChromeOS::OnFocus() {
@@ -172,7 +172,7 @@ void InputMethodChromeOS::OnCaretBoundsChanged(const TextInputClient* client) {
}
chromeos::IBusPanelCandidateWindowHandlerInterface* candidate_window =
- chromeos::IBusBridge::Get()->GetCandidateWindowHandler();
+ chromeos::IMEBridge::Get()->GetCandidateWindowHandler();
if (!candidate_window)
return;
candidate_window->SetCursorBounds(rect, composition_head);
@@ -306,7 +306,7 @@ void InputMethodChromeOS::UpdateContextFocusState() {
// Propagate the focus event to the candidate window handler which also
// manages the input method mode indicator.
chromeos::IBusPanelCandidateWindowHandlerInterface* candidate_window =
- chromeos::IBusBridge::Get()->GetCandidateWindowHandler();
+ chromeos::IMEBridge::Get()->GetCandidateWindowHandler();
if (candidate_window)
candidate_window->FocusStateChanged(context_focused_);
@@ -322,7 +322,7 @@ void InputMethodChromeOS::UpdateContextFocusState() {
if (old_context_focused && (!context_focused_ || input_type_change))
GetEngine()->FocusOut();
if (context_focused_ && (!old_context_focused || input_type_change)) {
- chromeos::IBusEngineHandlerInterface::InputContext context(
+ chromeos::IMEEngineHandlerInterface::InputContext context(
current_text_input_type, GetTextInputMode());
GetEngine()->FocusIn(context);
OnCaretBoundsChanged(GetTextInputClient());
@@ -493,7 +493,7 @@ void InputMethodChromeOS::UpdatePreeditText(const chromeos::IBusText& text,
if (!CanComposeInline()) {
chromeos::IBusPanelCandidateWindowHandlerInterface* candidate_window =
- chromeos::IBusBridge::Get()->GetCandidateWindowHandler();
+ chromeos::IMEBridge::Get()->GetCandidateWindowHandler();
if (candidate_window)
candidate_window->UpdatePreeditText(text.text(), cursor_pos, visible);
}
diff --git a/ui/base/ime/input_method_chromeos.h b/ui/base/ime/input_method_chromeos.h
index 06f6c25..b2708ae 100644
--- a/ui/base/ime/input_method_chromeos.h
+++ b/ui/base/ime/input_method_chromeos.h
@@ -13,7 +13,7 @@
#include "base/memory/scoped_ptr.h"
#include "base/memory/weak_ptr.h"
#include "ui/base/ime/chromeos/character_composer.h"
-#include "ui/base/ime/chromeos/ibus_bridge.h"
+#include "ui/base/ime/chromeos/ime_bridge.h"
#include "ui/base/ime/composition_text.h"
#include "ui/base/ime/input_method_base.h"
@@ -112,7 +112,7 @@ class UI_BASE_EXPORT InputMethodChromeOS
// Hides the composition text.
void HidePreeditText();
- // Callback function for IBusEngineHandlerInterface::ProcessKeyEvent.
+ // Callback function for IMEEngineHandlerInterface::ProcessKeyEvent.
void ProcessKeyEventDone(uint32 id, ui::KeyEvent* event, bool is_handled);
// All pending key events. Note: we do not own these object, we just save
diff --git a/ui/base/ime/input_method_chromeos_unittest.cc b/ui/base/ime/input_method_chromeos_unittest.cc
index 0ca30ff0..b7ea4b1 100644
--- a/ui/base/ime/input_method_chromeos_unittest.cc
+++ b/ui/base/ime/input_method_chromeos_unittest.cc
@@ -16,7 +16,7 @@
#include "chromeos/ime/ibus_keymap.h"
#include "chromeos/ime/ibus_text.h"
#include "testing/gtest/include/gtest/gtest.h"
-#include "ui/base/ime/chromeos/ibus_bridge.h"
+#include "ui/base/ime/chromeos/ime_bridge.h"
#include "ui/base/ime/chromeos/mock_ime_candidate_window_handler.h"
#include "ui/base/ime/chromeos/mock_ime_engine_handler.h"
#include "ui/base/ime/input_method_chromeos.h"
@@ -31,7 +31,7 @@ using base::UTF16ToUTF8;
namespace ui {
namespace {
-typedef chromeos::IBusEngineHandlerInterface::KeyEventDoneCallback
+typedef chromeos::IMEEngineHandlerInterface::KeyEventDoneCallback
KeyEventCallback;
uint32 GetOffsetInUTF16(const std::string& utf8_string, uint32 utf8_offset) {
@@ -205,16 +205,16 @@ class InputMethodChromeOSTest : public internal::InputMethodDelegate,
// testing::Test overrides:
virtual void SetUp() OVERRIDE {
- chromeos::IBusBridge::Initialize();
+ chromeos::IMEBridge::Initialize();
mock_ime_engine_handler_.reset(
new chromeos::MockIMEEngineHandler());
- chromeos::IBusBridge::Get()->SetCurrentEngineHandler(
+ chromeos::IMEBridge::Get()->SetCurrentEngineHandler(
mock_ime_engine_handler_.get());
mock_ime_candidate_window_handler_.reset(
new chromeos::MockIMECandidateWindowHandler());
- chromeos::IBusBridge::Get()->SetCandidateWindowHandler(
+ chromeos::IMEBridge::Get()->SetCandidateWindowHandler(
mock_ime_candidate_window_handler_.get());
ime_.reset(new TestableInputMethodChromeOS(this));
@@ -225,11 +225,11 @@ class InputMethodChromeOSTest : public internal::InputMethodDelegate,
if (ime_.get())
ime_->SetFocusedTextInputClient(NULL);
ime_.reset();
- chromeos::IBusBridge::Get()->SetCurrentEngineHandler(NULL);
- chromeos::IBusBridge::Get()->SetCandidateWindowHandler(NULL);
+ chromeos::IMEBridge::Get()->SetCurrentEngineHandler(NULL);
+ chromeos::IMEBridge::Get()->SetCandidateWindowHandler(NULL);
mock_ime_engine_handler_.reset();
mock_ime_candidate_window_handler_.reset();
- chromeos::IBusBridge::Shutdown();
+ chromeos::IMEBridge::Shutdown();
}
// ui::internal::InputMethodDelegate overrides:
diff --git a/ui/base/ime/input_method_initializer.cc b/ui/base/ime/input_method_initializer.cc
index 87e85ef..03291dc 100644
--- a/ui/base/ime/input_method_initializer.cc
+++ b/ui/base/ime/input_method_initializer.cc
@@ -5,7 +5,7 @@
#include "ui/base/ime/input_method_initializer.h"
#if defined(OS_CHROMEOS)
-#include "ui/base/ime/chromeos/ibus_bridge.h"
+#include "ui/base/ime/chromeos/ime_bridge.h"
#elif defined(USE_AURA) && defined(OS_LINUX) && !defined(USE_OZONE)
#include "ui/base/ime/input_method_auralinux.h"
#include "ui/base/ime/linux/fake_input_method_context_factory.h"
@@ -28,7 +28,7 @@ namespace ui {
void InitializeInputMethod() {
#if defined(OS_CHROMEOS)
- chromeos::IBusBridge::Initialize();
+ chromeos::IMEBridge::Initialize();
#elif defined(USE_AURA) && defined(OS_LINUX) && !defined(USE_OZONE)
InputMethodAuraLinux::Initialize();
#elif defined(OS_WIN)
@@ -39,7 +39,7 @@ void InitializeInputMethod() {
void ShutdownInputMethod() {
#if defined(OS_CHROMEOS)
- chromeos::IBusBridge::Shutdown();
+ chromeos::IMEBridge::Shutdown();
#elif defined(OS_WIN)
internal::DestroySharedInputMethod();
if (base::win::IsTSFAwareRequired())
@@ -49,7 +49,7 @@ void ShutdownInputMethod() {
void InitializeInputMethodForTesting() {
#if defined(OS_CHROMEOS)
- chromeos::IBusBridge::Initialize();
+ chromeos::IMEBridge::Initialize();
#elif defined(USE_AURA) && defined(OS_LINUX) && !defined(USE_OZONE)
if (!g_linux_input_method_context_factory)
g_linux_input_method_context_factory = new FakeInputMethodContextFactory();
@@ -71,7 +71,7 @@ void InitializeInputMethodForTesting() {
void ShutdownInputMethodForTesting() {
#if defined(OS_CHROMEOS)
- chromeos::IBusBridge::Shutdown();
+ chromeos::IMEBridge::Shutdown();
#elif defined(USE_AURA) && defined(OS_LINUX) && !defined(USE_OZONE)
const LinuxInputMethodContextFactory* factory =
LinuxInputMethodContextFactory::instance();
diff --git a/ui/base/ime/chromeos/ibus_bridge.h b/ui/base/ime/chromeos/ime_bridge.h
index 59a1066..79af952 100644
--- a/ui/base/ime/chromeos/ibus_bridge.h
+++ b/ui/base/ime/chromeos/ime_bridge.h
@@ -1,10 +1,9 @@
-// Copyright 2013 The Chromium Authors. All rights reserved.
+// Copyright 2014 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-// TODO(nona): Rename this file to ime_bridge.h
-#ifndef UI_BASE_IME_CHROMEOS_IBUS_BRIDGE_H_
-#define UI_BASE_IME_CHROMEOS_IBUS_BRIDGE_H_
+#ifndef UI_BASE_IME_CHROMEOS_IME_BRIDGE_H_
+#define UI_BASE_IME_CHROMEOS_IME_BRIDGE_H_
#include <string>
#include "base/basictypes.h"
@@ -42,7 +41,7 @@ class UI_BASE_EXPORT IBusInputContextHandlerInterface {
// A interface to handle the engine handler method call.
-class UI_BASE_EXPORT IBusEngineHandlerInterface {
+class UI_BASE_EXPORT IMEEngineHandlerInterface {
public:
typedef base::Callback<void (bool consumed)> KeyEventDoneCallback;
@@ -63,7 +62,7 @@ class UI_BASE_EXPORT IBusEngineHandlerInterface {
ui::TextInputMode mode;
};
- virtual ~IBusEngineHandlerInterface() {}
+ virtual ~IMEEngineHandlerInterface() {}
// Called when the Chrome input field get the focus.
virtual void FocusIn(const InputContext& input_context) = 0;
@@ -100,7 +99,7 @@ class UI_BASE_EXPORT IBusEngineHandlerInterface {
uint32 anchor_pos) = 0;
protected:
- IBusEngineHandlerInterface() {}
+ IMEEngineHandlerInterface() {}
};
// A interface to handle the candidate window related method call.
@@ -130,11 +129,11 @@ class UI_BASE_EXPORT IBusPanelCandidateWindowHandlerInterface {
};
// IBusBridge provides access of each IME related handler. This class
// is used for IME implementation.
-class UI_BASE_EXPORT IBusBridge {
+class UI_BASE_EXPORT IMEBridge {
public:
- virtual ~IBusBridge();
+ virtual ~IMEBridge();
// Allocates the global instance. Must be called before any calls to Get().
static void Initialize();
@@ -142,8 +141,8 @@ class UI_BASE_EXPORT IBusBridge {
// Releases the global instance.
static void Shutdown();
- // Returns IBusBridge global instance. Initialize() must be called first.
- static IBusBridge* Get();
+ // Returns IMEBridge global instance. Initialize() must be called first.
+ static IMEBridge* Get();
// Returns current InputContextHandler. This function returns NULL if input
// context is not ready to use.
@@ -158,26 +157,26 @@ class UI_BASE_EXPORT IBusBridge {
// |engine_id| must not be empty and |handler| must not be null.
virtual void SetEngineHandler(
const std::string& engine_id,
- IBusEngineHandlerInterface* handler) = 0;
+ IMEEngineHandlerInterface* handler) = 0;
- // Returns IBusEngineHandlerInterface* mapped by |engine_id|. NULL is
+ // Returns IMEEngineHandlerInterface* mapped by |engine_id|. NULL is
// returned if |engine_id| is not mapped any engines.
- virtual IBusEngineHandlerInterface* GetEngineHandler(
+ virtual IMEEngineHandlerInterface* GetEngineHandler(
const std::string& engine_id) = 0;
// Updates current EngineHandler. If there is no active engine service, pass
// NULL for |handler|. Caller must release |handler|.
- virtual void SetCurrentEngineHandler(IBusEngineHandlerInterface* handler) = 0;
+ virtual void SetCurrentEngineHandler(IMEEngineHandlerInterface* handler) = 0;
// Updates current EngineHandler by Engine ID. If there is no active
// engine service, pass an empty string for |engine_id|. The set
- // IBusEngineHandlerInterface is returned.
- virtual IBusEngineHandlerInterface* SetCurrentEngineHandlerById(
+ // IMEEngineHandlerInterface is returned.
+ virtual IMEEngineHandlerInterface* SetCurrentEngineHandlerById(
const std::string& engine_id) = 0;
// Returns current EngineHandler. This function returns NULL if current engine
// is not ready to use.
- virtual IBusEngineHandlerInterface* GetCurrentEngineHandler() const = 0;
+ virtual IMEEngineHandlerInterface* GetCurrentEngineHandler() const = 0;
// Returns current CandidateWindowHandler. This function returns NULL if
// current candidate window is not ready to use.
@@ -190,12 +189,12 @@ class UI_BASE_EXPORT IBusBridge {
IBusPanelCandidateWindowHandlerInterface* handler) = 0;
protected:
- IBusBridge();
+ IMEBridge();
private:
- DISALLOW_COPY_AND_ASSIGN(IBusBridge);
+ DISALLOW_COPY_AND_ASSIGN(IMEBridge);
};
} // namespace chromeos
-#endif // UI_BASE_IME_CHROMEOS_IBUS_BRIDGE_H_
+#endif // UI_BASE_IME_CHROMEOS_IME_BRIDGE_H_
@@ -130,11 +129,11 @@ class UI_BASE_EXPORT IBusPanelCandidateWindowHandlerInterface {
};
-// IBusBridge provides access of each IME related handler. This class
+// IMEBridge provides access of each IME related handler. This class
// is used for IME implementation.